@@ -21,11 +21,21 @@ use XSLoader;
 our @EXPORT    = qw();
 our @EXPORT_OK = qw(load getloadavg proc_loadavg uptime);
 
-our $VERSION = '0.28'; # TRIAL
+our $VERSION = '0.29'; # TRIAL
 
 XSLoader::load 'Sys::CpuLoad', $VERSION;
 
 
+our $LOAD;
+
+sub load {
+    return getloadavg(@_)   if $LOAD eq 'getloadavg';
+    return proc_loadavg(@_) if $LOAD eq 'proc_loadavg';
+    return uptime(@_)       if $LOAD eq 'uptime';
+    die "Unknown function: $LOAD";
+}
+
+
 sub proc_loadavg {
 
     if ( -r '/proc/loadavg' ) {
@@ -43,6 +53,7 @@ sub proc_loadavg {
     return undef;
 }
 
+
 our $UPTIME;
 
 sub uptime {
@@ -67,16 +78,13 @@ sub BEGIN {
     my $os   = lc $^O;
 
     if ( $os =~ /^(darwin|dragonfly|(free|net|open)bsd|linux|solaris|sunos)$/ ) {
-        no strict 'refs'; ## no critic (ProhibitNoStrict)
-        *{"${this}::load"} = \&getloadavg;
+        $LOAD = 'getloadavg';
     }
     elsif ( -r '/proc/loadavg' && $os ne 'cygwin' ) {
-        no strict 'refs'; ## no critic (ProhibitNoStrict)
-        *{"${this}::load"} = \&proc_loadavg;
+        $LOAD = 'proc_loadavg';
     }
     else {
-        no strict 'refs'; ## no critic (ProhibitNoStrict)
-        *{"${this}::load"} = \&uptime;
+        $LOAD = 'uptime';
     }
 
 }
@@ -96,7 +104,7 @@ Sys::CpuLoad - retrieve system load averages
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
@@ -126,8 +134,19 @@ Otherwise, it will attempt to parse the output of C<uptime>.
 
 On error, it will return an array of C<undef> values.
 
+As of v0.29, you can override the default function by changing
+C<$Sys::CpuLoad::LOAD>:
+
+  use Sys::CpuLoad 'load';
+
+  no warnings 'once';
+
+  $Sys::CpuLoad::LOAD = 'uptimr';
+
+  @load = load();
+
 If you are writing code to work on multiple systems, you should use
-this function.  But if your code is intended for specific systems,
+the C<load> function.  But if your code is intended for specific systems,
 then you should use the appropriate function.
 
 =head2 getloadavg
@@ -200,7 +219,7 @@ Clinton Wong <clintdw@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Slaven Rezić Vincent Lefèvre
+=for stopwords Slaven Rezić Victor Wagner Dmitry Dorofeev Vincent Lefèvre
 
 =over 4
 
@@ -210,6 +229,14 @@ Slaven Rezić <slaven@rezic.de>
 
 =item *
 
+Victor Wagner
+
+=item *
+
+Dmitry Dorofeev <dima@yasp.com>
+
+=item *
+
 Vincent Lefèvre <vincent@vinc17.net>
 
 =back
